@@ -1,7 +1,7 @@
 package PICA::Data;
 use v5.14.1;
 
-our $VERSION = '1.22';
+our $VERSION = '1.23';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(pica_parser pica_writer pica_path pica_xml_struct
@@ -249,8 +249,6 @@ use PICA::Writer::Plain;
 use PICA::Writer::Binary;
 use PICA::Writer::PPXML;
 use PICA::Writer::JSON;
-use PICA::Writer::Fields;
-use PICA::Writer::Subfields;
 
 sub pica_parser {
     _pica_module('PICA::Parser', @_);
@@ -536,14 +534,6 @@ L<PICA::Writer::XML> for type C<xml> or C<picaxml> (PICA-XML)
 
 L<PICA::Writer::PPXML> for type C<ppxml> (PicaPlus-XML)
 
-=item
-
-L<PICA::Writer::Fields> for type C<fields> (summary of used fields)
-
-=item
-
-L<PICA::Writer::Subfields> for type C<subfields> (summary of used subfields)
-
 =back
 
 =head2 pica_string( $record [, $type [, @options] ] )
